@@ -119,7 +119,7 @@ def parse_tuple(G: Generic, obj: Any, **kwargs):
 
 @parser(Dict)
 def parse_dict(G: Generic, obj: Any, **kwargs):
-    assert issubclass(type(obj), dict), f"Unable to parse from {type(obj)} to {G}"
+    assert issubclass(type(obj), Mapping), f"Unable to parse from {type(obj)} to {G}"
     key_type, val_type = get_args(G)
     return {
         parse(key_type, key, **kwargs): parse(val_type, val, **kwargs)
